==> jruby_1.7.22.orig.tar.gz: jruby-1.7.22/test/externals/ruby1.9/excludes/TestIO_M17N.rb <==
exclude :test_cbuf, "needs investigation"
exclude :test_cr_decorator_on_stdout, "needs investigation"
exclude :test_crlf_decorator_on_stdout, "needs investigation"
exclude :test_dup, "needs investigation"
exclude :test_dup_undef, "needs investigation"
exclude :test_error_nonascii, "needs investigation"
exclude :test_getc_invalid, "needs investigation"
exclude :test_getc_invalid2, "needs investigation"
exclude :test_getc_invalid3, "needs investigation"
exclude :test_getc_newlineconv_invalid, "needs investigation"
exclude :test_getc_stateful_conversion, "needs investigation"
exclude :test_gets_invalid, "needs investigation"
exclude :test_gets_limit, "needs investigation"
exclude :test_inspect_nonascii, "needs investigation"
exclude :test_invalid_r, "needs investigation"
exclude :test_lf_decorator_on_stdout, "needs investigation"
exclude :test_nonascii_terminator, "needs investigation"
exclude :test_open_pipe_r_enc2, "needs investigation"
exclude :test_pipe, "needs investigation"
exclude :test_puts_widechar, "needs investigation"
exclude :test_read_all_invalid, "needs investigation"
exclude :test_read_mode, "needs investigation"
exclude :test_s_pipe_invalid, "needs investigation"
exclude :test_stdin_external_encoding_with_reopen, "needs investigation"
exclude :test_terminator_conversion2, "needs investigation"
exclude :test_terminator_stateful_conversion, "needs investigation"
exclude :test_textmode_decode_universal_newline_getc, "needs investigation"
exclude :test_textmode_decode_universal_newline_gets, "needs investigation"
exclude :test_textmode_decode_universal_newline_read, "needs investigation"
exclude :test_textmode_decode_universal_newline_utf16, "needs investigation"
exclude :test_textmode_paragraph_binaryread, "needs investigation"
exclude :test_textmode_paragraphmode, "needs investigation"
exclude :test_undef_r, "needs investigation"
exclude :test_undef_w_stateful, "needs investigation"
exclude :test_undef_w_stateless, "needs investigation"
exclude :test_ungetc_int, "needs investigation"
exclude :test_ungetc_stateful_conversion2, "needs investigation"
exclude :test_ungetc_str, "needs investigation"
exclude :test_w_xml_attr, "needs investigation"
exclude :test_write_conversion_anyenc_stateful, "needs investigation"
exclude :test_write_conversion_anyenc_stateful_nosync, "needs investigation"
exclude :test_write_conversion_fixenc, "needs investigation"
exclude :test_write_mode, "needs investigation"

==> jruby_1.7.26.orig.tar.gz: jruby-1.7.26/test/externals/ruby1.9/excludes/TestIO_M17N.rb <==
windows = RbConfig::CONFIG['host_os'] =~ /mswin|mingw/

exclude :test_cbuf, "needs investigation"
exclude :test_cr_decorator_on_stdout, "needs investigation"
exclude :test_crlf_decorator_on_stdout, "needs investigation"
exclude :test_default_mode_on_unix, "needs investigation" if windows
exclude :test_dup, "needs investigation"
exclude :test_dup_undef, "needs investigation"
exclude :test_error_nonascii, "needs investigation"
exclude :test_getc_invalid, "needs investigation"
exclude :test_getc_invalid2, "needs investigation"
exclude :test_getc_invalid3, "needs investigation"
exclude :test_getc_newlineconv_invalid, "needs investigation"
exclude :test_getc_stateful_conversion, "needs investigation"
exclude :test_gets_invalid, "needs investigation"
exclude :test_gets_limit, "needs investigation"
exclude :test_inspect_nonascii, "needs investigation"
exclude :test_invalid_r, "needs investigation"
exclude :test_lf_decorator_on_stdout, "needs investigation"
exclude :test_nonascii_terminator, "needs investigation"
exclude :test_open_pipe_r_enc2, "needs investigation"
exclude :test_pipe, "needs investigation"
exclude :test_puts_widechar, "needs investigation"
exclude :test_read_all_invalid, "needs investigation"
exclude :test_read_encoding, "needs investigation" if windows
exclude :test_read_mode, "needs investigation"
exclude :test_s_pipe_invalid, "needs investigation"
exclude :test_stdin_external_encoding_with_reopen, "needs investigation"
exclude :test_terminator_conversion2, "needs investigation"
exclude :test_terminator_stateful_conversion, "needs investigation"
exclude :test_textmode_decode_universal_newline_getc, "needs investigation"
exclude :test_textmode_decode_universal_newline_gets, "needs investigation"
exclude :test_textmode_decode_universal_newline_read, "needs investigation"
exclude :test_textmode_decode_universal_newline_utf16, "needs investigation"
exclude :test_textmode_paragraph_binaryread, "needs investigation"
exclude :test_textmode_paragraphmode, "needs investigation"
exclude :test_undef_r, "needs investigation"
exclude :test_undef_w_stateful, "needs investigation"
exclude :test_undef_w_stateless, "needs investigation"
exclude :test_ungetc_int, "needs investigation"
exclude :test_ungetc_stateful_conversion2, "needs investigation"
exclude :test_ungetc_str, "needs investigation"
exclude :test_w_xml_attr, "needs investigation"
exclude :test_write_conversion_anyenc_stateful, "needs investigation"
exclude :test_write_conversion_anyenc_stateful_nosync, "needs investigation"
exclude :test_write_conversion_fixenc, "needs investigation"
exclude :test_write_mode, "needs investigation"
exclude :test_write_mode_fail, "needs investigation" if windows
